@@ -72,6 +72,23 @@ def main(argv=None):
         "otf": ("xlf", convertodf),  # Formula template
         "oti": ("xlf", convertodf),  # Image template
         "oth": ("xlf", convertodf),  # Web page template
+        "sxw": ("xliff", convertodf),
+        "odt": ("xliff", convertodf),  # Text
+        "ods": ("xliff", convertodf),  # Spreadsheet
+        "odp": ("xliff", convertodf),  # Presentation
+        "odg": ("xliff", convertodf),  # Drawing
+        "odc": ("xliff", convertodf),  # Chart
+        "odf": ("xliff", convertodf),  # Formula
+        "odi": ("xliff", convertodf),  # Image
+        "odm": ("xliff", convertodf),  # Master Document
+        "ott": ("xliff", convertodf),  # Text template
+        "ots": ("xliff", convertodf),  # Spreadsheet template
+        "otp": ("xliff", convertodf),  # Presentation template
+        "otg": ("xliff", convertodf),  # Drawing template
+        "otc": ("xliff", convertodf),  # Chart template
+        "otf": ("xliff", convertodf),  # Formula template
+        "oti": ("xliff", convertodf),  # Image template
+        "oth": ("xliff", convertodf),  # Web page template
     }
     parser = convert.ConvertOptionParser(formats, description=__doc__)
     parser.run(argv)
