@@ -35,8 +35,22 @@ class po2txt(object):
     best to give it a template file otherwise will just concat msgstrs
     """
 
-    def __init__(self, wrap=None):
-        self.wrap = wrap
+    def __init__(self, input_file, output_file, template_file=None,
+                 include_fuzzy=False, output_threshold=None, encoding='utf-8',
+                 wrap=None):
+        """Initialize the converter."""
+        self.source_store = factory.getobject(input_file)
+
+        self.should_output_store = convert.should_output_store(
+            self.source_store, output_threshold
+        )
+        if self.should_output_store:
+            self.include_fuzzy = include_fuzzy
+            self.encoding = encoding
+            self.wrap = wrap
+
+            self.output_file = output_file
+            self.template_file = template_file
 
     def wrapmessage(self, message):
         """rewraps text as required"""
@@ -45,64 +59,72 @@ class po2txt(object):
         return "\n".join([textwrap.fill(line, self.wrap, replace_whitespace=False)
                           for line in message.split("\n")])
 
-    def convertstore(self, inputstore, includefuzzy):
-        """converts a file to txt format"""
+    def convert_store(self):
+        """Convert a source file to a target file."""
         txtresult = ""
-        for unit in inputstore.units:
+        for unit in self.source_store.units:
             if not unit.istranslatable():
                 continue
-            if unit.istranslated() or (includefuzzy and unit.isfuzzy()):
+            if unit.istranslated() or (self.include_fuzzy and unit.isfuzzy()):
                 txtresult += self.wrapmessage(unit.target) + "\n\n"
             else:
                 txtresult += self.wrapmessage(unit.source) + "\n\n"
         return txtresult.rstrip()
 
-    def mergestore(self, inputstore, templatetext, includefuzzy):
-        """converts a file to txt format"""
-        txtresult = templatetext
+    def merge_stores(self):
+        """Convert a source file to a target file using a template file.
+
+        Source file is in source format, while target and template files use
+        target format.
+        """
+        txtresult = self.template_file.read().decode(self.encoding)
         # TODO: make a list of blocks of text and translate them individually
         # rather than using replace
-        for unit in inputstore.units:
+        for unit in self.source_store.units:
             if not unit.istranslatable():
                 continue
-            if not unit.isfuzzy() or includefuzzy:
+            if not unit.isfuzzy() or self.include_fuzzy:
                 txtsource = unit.source
                 txttarget = self.wrapmessage(unit.target)
                 if unit.istranslated():
                     txtresult = txtresult.replace(txtsource, txttarget)
         return txtresult
 
+    def run(self):
+        """Run the converter."""
+        if not self.should_output_store:
+            return False
 
-def converttxt(inputfile, outputfile, templatefile, wrap=None,
-               includefuzzy=False, encoding='utf-8', outputthreshold=None):
-    """reads in stdin using fromfileclass, converts using convertorclass, writes to stdout"""
-    inputstore = factory.getobject(inputfile)
+        if self.template_file is None:
+            outputstring = self.convert_store()
+        else:
+            outputstring = self.merge_stores()
 
-    if not convert.should_output_store(inputstore, outputthreshold):
-        return False
+        self.output_file.write(outputstring.encode('utf-8'))
+        return True
 
-    convertor = po2txt(wrap=wrap)
 
-    if templatefile is None:
-        outputstring = convertor.convertstore(inputstore, includefuzzy)
-    else:
-        templatestring = templatefile.read().decode(encoding)
-        outputstring = convertor.mergestore(inputstore, templatestring, includefuzzy)
+def run_converter(inputfile, outputfile, templatefile=None, wrap=None,
+                  includefuzzy=False, encoding='utf-8', outputthreshold=None):
+    """Wrapper around converter."""
+    return po2txt(inputfile, outputfile, templatefile,
+                  include_fuzzy=includefuzzy, output_threshold=outputthreshold,
+                  encoding=encoding, wrap=wrap).run()
 
-    outputfile.write(outputstring.encode('utf-8'))
-    return True
+
+formats = {
+    ("po", "txt"): ("txt", run_converter),
+    ("po"): ("txt", run_converter),
+    ("xlf", "txt"): ("txt", run_converter),
+    ("xlf"): ("txt", run_converter),
+    ("xliff", "txt"): ("txt", run_converter),
+    ("xliff"): ("txt", run_converter),
+}
 
 
 def main(argv=None):
-    formats = {
-        ("po", "txt"): ("txt", converttxt),
-        ("po"): ("txt", converttxt),
-        ("xlf", "txt"): ("txt", converttxt),
-        ("xlf"): ("txt", converttxt),
-        ("xliff", "txt"): ("txt", converttxt),
-        ("xliff"): ("txt", converttxt),
-    }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True, description=__doc__)
+    parser = convert.ConvertOptionParser(formats, usetemplates=True,
+                                         description=__doc__)
     parser.add_option(
         "", "--encoding", dest="encoding", default='utf-8', type="string",
         help="The encoding of the template file (default: UTF-8)")
