@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
 from pytest import mark
@@ -8,7 +7,7 @@ from translate.misc import wStringIO
 from translate.storage import dtd, po
 
 
-class TestDTD2PO:
+class TestDTD2PO(object):
 
     def dtd2po(self, dtdsource, dtdtemplate=None):
         """helper that converts dtd source to po source without requiring files"""
@@ -121,7 +120,7 @@ class TestDTD2PO:
 <!ENTITY alwaysCheckDefault.height  "3em">
 '''
         pofile = self.dtd2po(dtdsource)
-        posource = str(pofile)
+        posource = bytes(pofile).decode('utf-8')
         print(posource)
         assert posource.count('#.') == 5  # 1 Header extracted from, 3 comment lines, 1 autoinserted comment
 
@@ -156,7 +155,7 @@ class TestDTD2PO:
         dtdsource = '<!--LOCALIZATION NOTE (editorCheck.label): DONT_TRANSLATE -->\n' + \
             '<!ENTITY editorCheck.label "Composer">\n<!ENTITY editorCheck.accesskey "c">\n'
         pofile = self.dtd2po(dtdsource)
-        posource = str(pofile)
+        posource = bytes(pofile).decode('utf-8')
         # we need to decided what we're going to do here - see the comments in bug 30
         # this tests the current implementation which is that the DONT_TRANSLATE string is removed, but the other remains
         assert 'editorCheck.label' not in posource
@@ -179,19 +178,19 @@ class TestDTD2PO:
     def test_spaces_at_start_of_dtd_lines(self):
         """test that pretty print spaces at the start of subsequent DTD element lines are removed from the PO file, bug 79"""
         # Space at the end of the line
-        dtdsource = '<!ENTITY  noupdatesfound.intro "First line then \n' + \
-          '                                          next lines.">\n'
+        dtdsource = ('<!ENTITY  noupdatesfound.intro "First line then \n'
+                     '                                next lines.">\n')
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
         # We still need to decide how we handle line line breaks in the DTD entities.  It seems that we should actually
         # drop the line break but this has not been implemented yet.
-        assert pounit.source == "First line then \nnext lines."
+        assert pounit.source == "First line then next lines."
         # No space at the end of the line
-        dtdsource = '<!ENTITY  noupdatesfound.intro "First line then\n' + \
-          '                                          next lines.">\n'
+        dtdsource = ('<!ENTITY  noupdatesfound.intro "First line then\n'
+                     '                                next lines.">\n')
         pofile = self.dtd2po(dtdsource)
         pounit = self.singleelement(pofile)
-        assert pounit.source == "First line then \nnext lines."
+        assert pounit.source == "First line then next lines."
 
     def test_accesskeys_folding(self):
         """test that we fold accesskeys into message strings"""
@@ -210,18 +209,18 @@ class TestDTD2PO:
 
     def test_accesskeys_mismatch(self):
         """check that we can handle accesskeys that don't match and thus can't be folded into the .label entry"""
-        dtdsource = '<!ENTITY  fileSave.label "Save">\n' + \
-           '<!ENTITY  fileSave.accesskey "z">\n'
+        dtdsource = ('<!ENTITY  fileSave.label "Save">\n'
+                     '<!ENTITY  fileSave.accesskey "z">\n')
         pofile = self.dtd2po(dtdsource)
         assert self.countelements(pofile) == 2
 
     def test_carriage_return_in_multiline_dtd(self):
         """test that we create nice PO files when we find a \r\n in a multiline DTD element"""
-        dtdsource = '<!ENTITY  noupdatesfound.intro "First line then \r\n' + \
-          '                                          next lines.">\n'
+        dtdsource = ('<!ENTITY  noupdatesfound.intro "First line then \r\n'
+                     '                                next lines.">\n')
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert unit.source == "First line then \nnext lines."
+        assert unit.source == "First line then next lines."
 
     def test_multiline_with_blankline(self):
         """test that we can process a multiline entity that has a blank line in it, bug 331"""
@@ -233,9 +232,9 @@ Some other text
 ">'''
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert unit.source == "Some text \n \nSome other text"
+        assert unit.source == "Some text  Some other text"
 
-    def test_mulitline_closing_quotes(self):
+    def test_multiline_closing_quotes(self):
         """test that we support various styles and spaces after closing quotes on multiline entities"""
         dtdsource = '''
 <!ENTITY pref.plural '<span>opsies</span><span
@@ -243,7 +242,7 @@ Some other text
 '''
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
-        assert unit.source == '<span>opsies</span><span \nclass="noWin">preferences</span>'
+        assert unit.source == '<span>opsies</span><span class="noWin">preferences</span>'
 
     def test_preserving_spaces(self):
         """test that we preserve space that appear at the start of the first line of a DTD entity"""
@@ -257,7 +256,7 @@ Some other text
         pofile = self.dtd2po(dtdsource)
         unit = self.singleelement(pofile)
         print(repr(unit.source))
-        assert unit.source == " - with a newline \nand more text"
+        assert unit.source == " - with a newline and more text"
 
     def test_escaping_newline_tabs(self):
         """test that we handle all kinds of newline permutations"""
@@ -368,9 +367,9 @@ class TestDTD2POCommand(test_convert.TestConvertCommand, TestDTD2PO):
     convertmodule = dtd2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE", last=True)
