@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+from pytest import mark
+
 from translate.convert import po2prop, test_convert
 from translate.misc import wStringIO
 from translate.storage import po
@@ -62,6 +64,25 @@ class TestPO2Prop(object):
         print(propfile)
         assert propfile == propexpected
 
+    def test_no_value(self):
+        """check that we can handle keys without value"""
+        posource = '''#: KEY\nmsgctxt "KEY"\nmsgid ""\nmsgstr ""\n'''
+        proptemplate = '''KEY = \n'''
+        propexpected = '''KEY = \n'''
+        propfile = self.merge2prop(proptemplate, posource)
+        print(propfile)
+        assert propfile == propexpected
+
+    @mark.xfail(reason="This doesn't work as expected right now")
+    def test_no_separator(self):
+        """check that we can handle keys without separator"""
+        posource = '''#: KEY\nmsgctxt "KEY"\nmsgid ""\nmsgstr ""\n'''
+        proptemplate = '''KEY\n'''
+        propexpected = '''KEY\n'''
+        propfile = self.merge2prop(proptemplate, posource)
+        print(propfile)
+        assert propfile == propexpected
+
     def test_merging_blank_entries(self):
         """check that we can correctly merge entries that are blank in the template"""
         posource = r'''#: accesskey-accept
@@ -447,9 +468,9 @@ class TestPO2PropCommand(test_convert.TestConvertCommand, TestPO2Prop):
     convertmodule = po2prop
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "--fuzzy")
         options = self.help_check(options, "--threshold=PERCENT")
