@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 from translate.convert import po2ts, test_convert
 from translate.misc import wStringIO
 from translate.storage import po
@@ -30,6 +32,18 @@ msgstr "asdf"'''
         assert "<translation>asdf</translation>" in tsfile
         assert "<comment>" not in tsfile
 
+    def test_simple_unicode_unit(self):
+        """checks that a simple unit with unicode strings"""
+        minipo = r'''#: unicode.cpp
+msgid "ßource"
+msgstr "†arget"'''
+        tsfile = self.po2ts(minipo)
+        print(tsfile)
+        print(type(tsfile))
+        assert u"<name>unicode.cpp</name>" in tsfile
+        assert u"<source>ßource</source>" in tsfile
+        assert u"<translation>†arget</translation>" in tsfile
+
     def test_fullunit(self):
         """check that an entry with various settings is converted correctly"""
         posource = '''# Translator comment
@@ -83,8 +97,8 @@ class TestPO2TSCommand(test_convert.TestConvertCommand, TestPO2TS):
     """Tests running actual po2ts commands on files"""
     convertmodule = po2ts
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-c CONTEXT, --context=CONTEXT")
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE", last=True)
