@@ -20,10 +20,12 @@
 """This module represents the Southern Sotho language.
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
 class st(common.Common):
     """This class represents Southern Sotho."""
 
-    validdoublewords = [u"o", u"le", u"ba"]
+    validdoublewords = ["o", "le", "ba"]
