@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2010 Zuza Software Foundation
@@ -23,18 +22,22 @@
 .. seealso:: http://en.wikipedia.org/wiki/Uyghur_language
 """
 
+from __future__ import unicode_literals
+
 from translate.lang import common
 
 
 class ug(common.Common):
     """This class represents Uyghur."""
 
-    listseperator = u"، "
+    listseperator = "، "
 
     puncdict = {
-        u",": u"،",
-        u";": u"؛",
-        u"?": u"؟",
+        ",": "،",
+        ";": "؛",
+        "?": "؟",
     }
 
-    ignoretests = ["startcaps", "simplecaps", "acronyms"]
+    ignoretests = {
+        'all': ["acronyms", "simplecaps", "startcaps"],
+    }
