@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2006 Zuza Software Foundation
@@ -17,5 +16,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, see <http://www.gnu.org/licenses/>.
-"""translate.services is part of the translate toolkit.
-It provides network services for interacting with the toolkit"""
+
+"""translate.services is part of the translate toolkit.  It provides network
+services for interacting with the toolkit
+"""
