@@ -1,4 +1,3 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 #
 # Copyright 2004-2006,2008 Zuza Software Foundation
@@ -22,6 +21,7 @@
 """module for parsing html files for translation"""
 
 import re
+import six
 
 from six.moves import html_parser
 from six.moves.html_entities import name2codepoint
@@ -98,7 +98,7 @@ class htmlunit(base.TranslationUnit):
 
     def __init__(self, source=None):
         self.locations = []
-        self.setsource(source)
+        self.source = source
 
     def getsource(self):
         #TODO: Rethink how clever we should try to be with html entities.
@@ -170,12 +170,13 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
 
     def __init__(self, includeuntaggeddata=None, inputfile=None,
                  callback=None):
-        self.units = []
+        base.TranslationStore.__init__(self)
         self.filename = getattr(inputfile, 'name', None)
         self.currentblock = u""
         self.currentcomment = u""
         self.currenttag = None
         self.currentpos = -1
+        self.currentoffset = -1
         self.tag_path = []
         self.filesrc = u""
         self.currentsrc = u""
@@ -185,7 +186,8 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         else:
             self.callback = callback
         self.includeuntaggeddata = includeuntaggeddata
-        html_parser.HTMLParser.__init__(self)
+        htmlargs = {'convert_charrefs': True} if six.PY34 else {}
+        html_parser.HTMLParser.__init__(self, **htmlargs)
 
         if inputfile is not None:
             htmlsrc = inputfile.read()
@@ -195,7 +197,7 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
     def _simple_callback(self, string):
         return string
 
-    ENCODING_RE = re.compile('''<meta.*
+    ENCODING_RE = re.compile(b'''<meta.*
                                 content.*=.*?charset.*?=\s*?
                                 ([^\s]*)
                                 \s*?["']\s*?>
@@ -208,18 +210,14 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         """
 
         result = self.ENCODING_RE.findall(htmlsrc)
-        encoding = None
         if result:
-            encoding = result[0]
-        return encoding
+            self.encoding = result[0].decode('ascii')
+        return self.encoding
 
     def do_encoding(self, htmlsrc):
         """Return the html text properly encoded based on a charset."""
-        charset = self.guess_encoding(htmlsrc)
-        if charset:
-            return htmlsrc.decode(charset)
-        else:
-            return htmlsrc.decode('utf-8')
+        self.guess_encoding(htmlsrc)
+        return htmlsrc.decode(self.encoding)
 
     def pi_escape(self, text):
         """Replaces all instances of process instruction with placeholders,
@@ -231,9 +229,13 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         The purpose of this is to remove all potential "tag-like" code from
         inside PHP.  The hash looks nothing like an HTML tag, but the following
         PHP::
+
           $a < $b ? $c : ($d > $e ? $f : $g)
+
         looks like it contains an HTML tag::
+
           < $b ? $c : ($d >
+
         to nearly any regex.  Hence, we replace all contents of PHP with simple
         strings to help our regexes out.
 
@@ -262,15 +264,15 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         text = normalize_html(text)
         if self.has_translatable_content(text):
             unit = self.addsourceunit(text)
-            unit.addlocation("%s+%s:%d" %
-                              (self.filename, ".".join(self.tag_path),
-                               self.currentpos))
+            unit.addlocation("%s+%s:%d-%d" %
+                             (self.filename, ".".join(self.tag_path),
+                              self.currentpos, self.currentoffset))
             unit.addnote(self.currentcomment)
 
     def has_translatable_content(self, text):
         """Check if the supplied HTML snippet has any content that needs to be
-        translated."""
-
+        translated.
+        """
         text = text.strip()
         result = re.findall('(?i).*(charset.*=.*)', text)
         if len(result) == 1:
@@ -295,10 +297,11 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         if startend:
             selfclosing = u" /"
         if attrs != [] and attrs is not None:
-            return u"<%(tag)s %(attrs)s%(selfclosing)s>" % \
-                    {"tag": tag,
-                     "attrs": " ".join(['%s="%s"' % pair for pair in attrs]),
-                     "selfclosing": selfclosing}
+            return u"<%(tag)s %(attrs)s%(selfclosing)s>" % {
+                "tag": tag,
+                "attrs": " ".join(['%s="%s"' % pair for pair in attrs]),
+                "selfclosing": selfclosing
+            }
         else:
             return u"<%(tag)s%(selfclosing)s>" % {"tag": tag,
                                                   "selfclosing": selfclosing}
@@ -316,6 +319,7 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         self.currentcomment = ""
         self.currenttag = tag
         self.currentpos = self.getpos()[0]
+        self.currentoffset = self.getpos()[1] + 1
         self.currentsrc = self.buildtag(tag, attrs)
 
     def endblock(self):
@@ -329,6 +333,7 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
         self.currentcomment = ""
         self.currenttag = None
         self.currentpos = -1
+        self.currentoffset = -1
         self.currentsrc = ""
 
     def handle_starttag(self, tag, attrs):
@@ -403,14 +408,14 @@ class htmlfile(html_parser.HTMLParser, base.TranslationStore):
 
     def handle_charref(self, name):
         """Handle entries in the form &#NNNN; e.g. &#8417;"""
-        self.handle_data(unichr(int(name)))
+        self.handle_data(six.unichr(int(name)))
 
     def handle_entityref(self, name):
         """Handle named entities of the form &aaaa; e.g. &rsquo;"""
         if name in ['gt', 'lt', 'amp']:
             self.handle_data("&%s;" % name)
         else:
-            self.handle_data(unichr(name2codepoint.get(name, u"&%s;" % name)))
+            self.handle_data(six.unichr(name2codepoint.get(name, u"&%s;" % name)))
 
     def handle_comment(self, data):
         # we can place comments above the msgid as translator comments!
