@@ -28,6 +28,7 @@ import six
 
 from lxml import etree
 
+from translate.lang import data
 from translate.misc.multistring import multistring
 from translate.misc.xml_helpers import setXMLspace
 from translate.storage import base, lisa, poheader, xliff
@@ -150,7 +151,7 @@ class PoXliffUnit(xliff.xliffunit):
 
     def gettarget(self):
         if self.hasplural():
-            strings = [unit.target for unit in self.units]
+            strings = [data.forceunicode(unit.target) for unit in self.units]
             if strings:
                 return multistring(strings)
             else:
@@ -376,7 +377,8 @@ class PoXliffFile(xliff.xlifffile, poheader.poheader):
             xml.seek(0)
             xmlsrc = xml.read()
             xml = xmlsrc
-        self.document = etree.fromstring(xml).getroottree()
+        parser = etree.XMLParser(resolve_entities=False)
+        self.document = etree.fromstring(xml, parser).getroottree()
         self.initbody()
         root_node = self.document.getroot()
         assert root_node.tag == self.namespaced(self.rootNode)
