@@ -76,6 +76,7 @@ wrapper = textwrap.TextWrapper(
     drop_whitespace=False)
 wrapper.wordsep_re = re.compile(
     r'(\s+|'                                  # any whitespace
+    r'[a-z0-9A-Z_-]+/|'                       # nicely split long URLs
     r'\w*\\.|'                                # any escape should not be split
     r'[\w\!\'\&\.\,\?]+\s+|'                  # space should go with a word
     r'[^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|'   # hyphenated words
@@ -83,22 +84,26 @@ wrapper.wordsep_re = re.compile(
 wrapper.wordsep_re_uni = re.compile(wrapper.wordsep_re.pattern, re.UNICODE)
 
 
-def quoteforpo(text):
+def quoteforpo(text, wrapper_obj=None):
     """Quotes the given text for a PO file, returning quoted and escaped lines
     """
     if text is None:
         return []
+    if wrapper_obj is None:
+        wrapper_obj = wrapper
     text = escapeforpo(text)
+    if wrapper_obj.width == -1:
+        return [u'"%s"' % text]
     lines = text.split(u"\\n")
     for i, l in enumerate(lines[:-1]):
         lines[i] = l + u"\\n"
 
     polines = []
     len_lines = len(lines)
-    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > 71:
+    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > wrapper_obj.width - 6:
         polines.append(u'""')
     for line in lines:
-        lns = wrapper.wrap(line)
+        lns = wrapper_obj.wrap(line)
         for ln in lns:
             polines.append(u'"%s"' % ln)
     return polines
@@ -184,9 +189,10 @@ class pounit(pocommon.pounit):
 
     # Our homegrown way to indicate what must be copied in a shallow
     # fashion
-    __shallow__ = ['_store']
+    __shallow__ = ['_store', 'wrapper']
 
-    def __init__(self, source=None, **kwargs):
+    def __init__(self, source=None, wrapper=None, **kwargs):
+        self.wrapper = wrapper
         self.obsolete = False
         self._initallcomments(blankall=True)
         self.prev_msgctxt = []
@@ -225,6 +231,9 @@ class pounit(pocommon.pounit):
             return multistring([singular, pluralform])
         return singular
 
+    def quote(self, text):
+        return quoteforpo(text, self.wrapper)
+
     def _set_source_vars(self, source):
         msgid = None
         msgid_plural = None
@@ -234,13 +243,13 @@ class pounit(pocommon.pounit):
         if isinstance(source, multistring):
             source = source.strings
         if isinstance(source, list):
-            msgid = quoteforpo(source[0])
+            msgid = self.quote(source[0])
             if len(source) > 1:
-                msgid_plural = quoteforpo(source[1])
+                msgid_plural = self.quote(source[1])
             else:
                 msgid_plural = []
         else:
-            msgid = quoteforpo(source)
+            msgid = self.quote(source)
             msgid_plural = []
         return msgid, msgid_plural
 
@@ -296,11 +305,11 @@ class pounit(pocommon.pounit):
         if isinstance(templates, list):
             templates = {0: templates}
         if isinstance(target, list):
-            self.msgstr = dict([(i, quoteforpo(target[i])) for i in range(len(target))])
+            self.msgstr = dict([(i, self.quote(target[i])) for i in range(len(target))])
         elif isinstance(target, dict):
-            self.msgstr = dict([(i, quoteforpo(targetstring)) for i, targetstring in six.iteritems(target)])
+            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in six.iteritems(target)])
         else:
-            self.msgstr = quoteforpo(target)
+            self.msgstr = self.quote(target)
     target = property(gettarget, settarget)
 
     def getalttrans(self):
@@ -578,7 +587,7 @@ class pounit(pocommon.pounit):
         return len(self.msgid_plural) > 0
 
     def parse(self, src):
-        return poparser.parse_unit(poparser.ParseState(BytesIO(src), pounit), self)
+        return poparser.parse_unit(poparser.ParseState(src.splitlines(True), pounit), self)
 
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
@@ -610,7 +619,7 @@ class pounit(pocommon.pounit):
                         comment = comment[:-len("\\n")]
                     #Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
-                partcomments = quoteforpo("_:%s" % "".join(combinedcomment))
+                partcomments = self.quote("_:%s" % "".join(combinedcomment))
             # comments first, no blank leader line needed
             partstr += "\n".join(partcomments)
             partstr = quote.rstripeol(partstr)
@@ -697,8 +706,7 @@ class pounit(pocommon.pounit):
 
         """
         location = data.forceunicode(location)
-        if location.find(" ") != -1:
-            location = pocommon.quote_plus(location)
+        location = pocommon.quote_plus(location)
         self.sourcecomments.append("#: %s\n" % location)
 
     def _extract_msgidcomments(self, text=None):
@@ -727,7 +735,7 @@ class pounit(pocommon.pounit):
 
     def setcontext(self, context):
         context = data.forceunicode(context)
-        self.msgctxt = quoteforpo(context)
+        self.msgctxt = self.quote(context)
 
     def getid(self):
         """Returns a unique identifier for this unit."""
@@ -750,21 +758,32 @@ class pofile(pocommon.pofile):
 
     UnitClass = pounit
 
+    def __init__(self, inputfile=None, width=None, **kwargs):
+        self.wrapper = copy.copy(wrapper)
+        if width is not None:
+            self.wrapper.width = width
+        super(pofile, self).__init__(inputfile, **kwargs)
+
+    def create_unit(self):
+        return self.UnitClass(wrapper=self.wrapper)
+
     def parse(self, input):
         """Parses the given file or file source string."""
         if hasattr(input, 'name'):
             self.filename = input.name
         elif not getattr(self, 'filename', ''):
             self.filename = ''
-        if isinstance(input, bytes):
-            input = BytesIO(input)
+        if not isinstance(input, bytes):
+            input = input.read()
+        input = iter(input.splitlines(True))
         # clear units to get rid of automatically generated headers before parsing
         self.units = []
-        poparser.parse_units(poparser.ParseState(input, pounit), self)
+        poparser.parse_units(poparser.ParseState(input, self.create_unit), self)
 
     def removeduplicates(self, duplicatestyle="merge"):
         """Make sure each msgid is unique ; merge comments etc from
-        duplicates into original"""
+        duplicates into original
+        """
         # TODO: can we handle consecutive calls to removeduplicates()? What
         # about files already containing msgctxt? - test
         id_dict = {}
@@ -798,7 +817,7 @@ class pofile(pocommon.pofile):
                     if not thepo.msgctxt == id_dict[id].msgctxt:
                         uniqueunits.append(thepo)
                     else:
-                        logger.warn(
+                        logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo.msgctxt,
                             thepo.source)
@@ -856,3 +875,7 @@ class pofile(pocommon.pofile):
         for unit in self.units:
             if not (unit.isheader() or unit.isobsolete()):
                 yield unit
+
+    def addunit(self, unit):
+        unit.wrapper = self.wrapper
+        super(pofile, self).addunit(unit)
