@@ -112,7 +112,8 @@ class TestPhpFile(test_monolingual.TestMonolingualStore):
 
     def test_simpledefinition_source(self):
         """checks that a simple php definition can be regenerated as source"""
-        phpsource = """$lang['mediaselect']='Bestand selectie';"""
+        phpsource = """<?php
+$lang['mediaselect'] = 'Bestand selectie';"""
         phpregen = self.phpregen(phpsource)
         assert phpsource + '\n' == phpregen
 
@@ -138,10 +139,10 @@ $foo = "bar";
         phpunit = phpfile.units[0]
         assert phpunit.name == "$foo"
         assert phpunit.source == "bar"
-        assert phpunit._comments == ["""/*""",
-                                     """ * Comment line 1""",
-                                     """ * Comment line 2""",
-                                     """ */"""]
+        assert phpunit._comments == ["""/*
+ * Comment line 1
+ * Comment line 2
+ */"""]
 
     def test_comment_blocks(self):
         """check that we don't process name value pairs in comment blocks"""
@@ -159,18 +160,35 @@ $lang[2] = "Yeah";
 
     def test_comment_output(self):
         """check that linebreaks and spacing is preserved when comments are output"""
-        # php.py uses single quotes and doesn't add spaces before or after '='
         phpsource = """/*
  * Comment line 1
  * Comment line 2
  */
-$foo='bar';
+$foo = 'bar';
 """
         phpfile = self.phpparse(phpsource)
         assert len(phpfile.units) == 1
         phpunit = phpfile.units[0]
         assert str(phpunit) == phpsource
 
+    def test_comment_add(self):
+        """check that comments are actually added"""
+        phpsource = """/* NOTE 1 */
+$foo = 'bar';
+"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$foo"
+        assert phpunit.source == "bar"
+        assert phpunit._comments == ['/* NOTE 1 */']
+        # Replace existing notes
+        phpunit.addnote('/* NOTE 2 */', None, 'replace')
+        # Set unknown note
+        phpunit.addnote('/* NOTE 2 */', 'unknown')
+        assert phpunit._comments == ['/* NOTE 2 */']
+        assert str(phpunit) == phpsource.replace('NOTE 1', 'NOTE 2')
+
     def test_multiline(self):
         """check that we preserve newlines in a multiline message"""
         phpsource = """$lang['multiline'] = "Line1%sLine2";"""
@@ -227,7 +245,6 @@ $foo='bar';
          'item 3' => 'value3',
       );'''
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[1]
         assert phpunit.name == "$lang->'item 3'"
@@ -238,7 +255,6 @@ $foo='bar';
         phpsource = """define("_FINISH", "Rematar");
 define('_POSTEDON', 'Enviado o');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_FINISH"'
@@ -252,7 +268,6 @@ define('_POSTEDON', 'Enviado o');"""
         phpsource = """define( "_FINISH", "Rematar");
 define( '_CM_POSTED', 'Enviado');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define( "_FINISH"'
@@ -266,7 +281,6 @@ define( '_CM_POSTED', 'Enviado');"""
         phpsource = """define("_RELOAD",       "Recargar");
 define('_CM_POSTED',    'Enviado');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_RELOAD"'
@@ -282,7 +296,6 @@ define('_CM_POSTED',    'Enviado');"""
         phpsource = """define( "_FINISH",       "Rematar");
 define(  '_UPGRADE_CHARSET',    'Upgrade charset');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define( "_FINISH"'
@@ -296,7 +309,6 @@ define(  '_UPGRADE_CHARSET',    'Upgrade charset');"""
         phpsource = """define("_POSTEDON","Enviado o");
 define('_UPGRADE_CHARSET','Upgrade charset');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_POSTEDON"'
@@ -312,7 +324,6 @@ define('_UPGRADE_CHARSET','Upgrade charset');"""
         phpsource = """define( "_FINISH","Rematar");
 define( '_CM_POSTED','Enviado');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define( "_FINISH"'
@@ -323,11 +334,10 @@ define( '_CM_POSTED','Enviado');"""
 
     def test_parsing_define_entries_with_quotes(self):
         """Parse define syntax for entries with quotes"""
-        phpsource = """define('_SETTINGS_COOKIEPREFIX', 'Prefixo da "cookie"');
+        phpsource = r"""define('_SETTINGS_COOKIEPREFIX', 'Prefixo da "cookie"');
 define('_YOUR_USERNAME', 'O seu nome de usuario: "cookie"');
 define("_REGISTER", "Register <a href=\"register.php\">here</a>");"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 3
         phpunit = phpfile.units[0]
         assert phpunit.name == "define('_SETTINGS_COOKIEPREFIX'"
@@ -344,16 +354,15 @@ define("_REGISTER", "Register <a href=\"register.php\">here</a>");"""
         phpsource = """define("_POSTEDON", "Enviado o");// Keep this short
 define('_CM_POSTED', 'Enviado'); // Posted date"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_POSTEDON"'
         assert phpunit.source == "Enviado o"
-        assert phpunit._comments == ["Keep this short"]
+        assert phpunit._comments == ["// Keep this short"]
         phpunit = phpfile.units[1]
         assert phpunit.name == "define('_CM_POSTED'"
         assert phpunit.source == "Enviado"
-        assert phpunit._comments == ["Posted date"]
+        assert phpunit._comments == ["// Posted date"]
 
     def test_parsing_define_double_slash_comments_before_entries(self):
         """Parse define syntax with double slash comments before the entries"""
@@ -364,7 +373,6 @@ define("_FINISH", "Rematar");
 // It appears besides posts
 define('_CM_POSTED', 'Enviado');"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_FINISH"'
@@ -382,7 +390,6 @@ define('_CM_POSTED', 'Enviado');"""
 define("_FINISH", "Rematar"     );
 define("_RELOAD", "Recargar");"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 3
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_POSTEDON"'
@@ -401,7 +408,6 @@ define("_RELOAD", "Recargar");"""
 $month_feb = 'Feb'  ;
 $month_mar = 'Mar';"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 3
         phpunit = phpfile.units[0]
         assert phpunit.name == '$month_jan'
@@ -413,7 +419,6 @@ $month_mar = 'Mar';"""
         assert phpunit.name == '$month_mar'
         assert phpunit.source == "Mar"
 
-    @mark.xfail(reason="Bug #1685")
     def test_parsing_arrays_no_trailing_comma(self):
         """parse the array syntax where we don't have a trailing comma.
         Bug #1685"""
@@ -461,6 +466,116 @@ $month_mar = 'Mar';"""
         assert phpunit.name == "$lang->'item2'"
         assert phpunit.source == "value2"
 
+    def test_parsing_arrays_declared_in_a_single_line(self):
+        """parse an array declared in a single line.
+        Bug #3629"""
+        phpsource = '''$lang = array( 'item1' => 'value1', 'item2' => 'value2', 'item3' => 'value3' );'''
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 3
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$lang->'item1'"
+        assert phpunit.source == "value1"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$lang->'item2'"
+        assert phpunit.source == "value2"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$lang->'item3'"
+        assert phpunit.source == "value3"
+
+    def test_parsing_arrays_with_no_keys(self):
+        """Parse an array with no keys."""
+        phpsource = """$days = array('Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday');"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 7
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Sunday"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Monday"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Tuesday"
+        phpunit = phpfile.units[3]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Wednesday"
+        phpunit = phpfile.units[4]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Thursday"
+        phpunit = phpfile.units[5]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Friday"
+        phpunit = phpfile.units[6]
+        assert phpunit.name == "$days->'None'"
+        assert phpunit.source == "Saturday"
+
+    @mark.xfail
+    def test_parsing_arrays_with_no_keys_assigned_to_array(self):
+        """Parse an array with no keys assigned to another array."""
+        phpsource = """$messages['days_short'] = array('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat');"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 7
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Sun"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Mon"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Tue"
+        phpunit = phpfile.units[3]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Wed"
+        phpunit = phpfile.units[4]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Thu"
+        phpunit = phpfile.units[5]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Fri"
+        phpunit = phpfile.units[6]
+        assert phpunit.name == "$messages->'days_short'->'None'"
+        assert phpunit.source == "Sat"
+
+    def test_parsing_nested_arrays_with_no_keys(self):
+        """Parse a nested array with no keys."""
+        phpsource = """$lang = array(array("key" => "value"));"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$lang->'None'->'key'"
+        assert phpunit.source == "value"
+
+    def test_assignment_in_line_where_multiline_comment_ends(self):
+        """Check parsing assignment in same line a multiline comment ends."""
+        phpsource = """<?php
+/*
+   Multi-line
+   comment
+*/ $messages['help'] = 'Help';
+"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$messages['help']"
+        assert phpunit.source == "Help"
+
+    def test_parsing_arrays_using_short_array_syntax(self):
+        """parse short array syntax.
+        Bug #3626"""
+        phpsource = '''$lang = [
+         'item1' => 'value1',
+         'item2' => 'value2'
+      ];'''
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 2
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$lang->'item1'"
+        assert phpunit.source == "value1"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$lang->'item2'"
+        assert phpunit.source == "value2"
+
     def test_parsing_nested_arrays(self):
         """parse the nested array syntax. Bug #2240"""
         phpsource = '''$app_list_strings = array(
@@ -500,10 +615,15 @@ $month_mar = 'Mar';"""
                 'Contacts' => 'Contacts',
                 'Accounts' => 'Accounts',
             ),
+            'tools' => array  (
+                'Pen' => 'Pen',
+                'Brush' => 'Brush',
+                'Pencil' => 'Pencil',
+            ),
             'FAQ' => 'FAQ',
         );'''
         phpfile = self.phpparse(phpsource)
-        assert len(phpfile.units) == 5
+        assert len(phpfile.units) == 8
         phpunit = phpfile.units[0]
         assert phpunit.name == "$app_list_strings->'Mailbox'"
         assert phpunit.source == "Mailbox"
@@ -517,10 +637,53 @@ $month_mar = 'Mar';"""
         assert phpunit.name == "$app_list_strings->'moduleList'->'Accounts'"
         assert phpunit.source == "Accounts"
         phpunit = phpfile.units[4]
+        assert phpunit.name == "$app_list_strings->'tools'->'Pen'"
+        assert phpunit.source == "Pen"
+        phpunit = phpfile.units[5]
+        assert phpunit.name == "$app_list_strings->'tools'->'Brush'"
+        assert phpunit.source == "Brush"
+        phpunit = phpfile.units[6]
+        assert phpunit.name == "$app_list_strings->'tools'->'Pencil'"
+        assert phpunit.source == "Pencil"
+        phpunit = phpfile.units[7]
         assert phpunit.name == "$app_list_strings->'FAQ'"
         assert phpunit.source == "FAQ"
 
-    @mark.xfail(reason="Bug #2647")
+    def test_parsing_unnamed_nested_arrays(self):
+        """parse the unnamed nested array."""
+
+        phpsource = '''return array  (
+            'name1' => 'target1',
+            'list1' => array(
+                'l1' => 'target_l1_1',
+                'l2' => 'target_l1_2',
+                'l3' => 'target_l1_3',
+            ),
+            'list2' => array(
+                'l1' => 'target_l2_1',
+                'l2' => 'target_l2_2',
+                'l3' => 'target_l2_3',
+            ),
+            'name2' => 'target2',
+        );'''
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 8
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "'name1'"
+        assert phpunit.source == "target1"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "'list1'->'l1'"
+        assert phpunit.source == "target_l1_1"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "'list1'->'l2'"
+        assert phpunit.source == "target_l1_2"
+        phpunit = phpfile.units[3]
+        assert phpunit.name == "'list1'->'l3'"
+        assert phpunit.source == "target_l1_3"
+        phpunit = phpfile.units[4]
+        assert phpunit.name == "'list2'->'l1'"
+        assert phpunit.source == "target_l2_1"
+
     def test_parsing_nested_arrays_with_array_declaration_in_next_line(self):
         """parse the nested array syntax with array declaration in the next
         line. Bug #2647"""
@@ -544,7 +707,28 @@ $month_mar = 'Mar';"""
         assert phpunit.name == "$lang->'item2'"
         assert phpunit.source == "value2"
 
-    @mark.xfail(reason="Bug #2648")
+    def test_parsing_array_with_newline_after_delimiter(self):
+        """Parse array with newline between key and value.
+
+        Bug #3628."""
+        phpsource = '''$lang = array(
+            'item1' => 'value1',
+            'frequency' =>
+                'Weekly',
+            'item2' => 'value2',
+        );'''
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 3
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$lang->'item1'"
+        assert phpunit.source == "value1"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$lang->'frequency'"
+        assert phpunit.source == "Weekly"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$lang->'item2'"
+        assert phpunit.source == "value2"
+
     def test_parsing_nested_arrays_with_blank_entries(self):
         """parse the nested array syntax with blank entries. Bug #2648"""
         phpsource = '''$lang = array(
@@ -568,7 +752,30 @@ $month_mar = 'Mar';"""
         assert phpunit.name == "$lang->'item2'"
         assert phpunit.source == "value2"
 
-    @mark.xfail(reason="Bug #2611")
+    def test_slashstar_in_string(self):
+        """ignore the /* comment delimiter when it is part of a string.
+        Bug #3627"""
+        phpsource = '''$definition['key'] = 'Value /* value continued';
+      $lang = array(
+         'somekey' => 'Some value',
+         'otherkey' => 'Other value /* continued',
+         'thirdkey' => 'Third value',
+      );'''
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 4
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$definition['key']"
+        assert phpunit.source == "Value /* value continued"
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$lang->'somekey'"
+        assert phpunit.source == "Some value"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$lang->'otherkey'"
+        assert phpunit.source == "Other value /* continued"
+        phpunit = phpfile.units[3]
+        assert phpunit.name == "$lang->'thirdkey'"
+        assert phpunit.source == "Third value"
+
     def test_parsing_simple_heredoc_syntax(self):
         """parse the heredoc syntax. Bug #2611"""
         phpsource = '''$month_jan = 'Jan';
@@ -587,7 +794,7 @@ FOOBAR;
 $month_mar = 'Mar';
         '''
         phpfile = self.phpparse(phpsource)
-        assert len(phpfile.units) == 3
+        assert len(phpfile.units) == 4
         phpunit = phpfile.units[0]
         assert phpunit.name == '$month_jan'
         assert phpunit.source == "Jan"
@@ -606,7 +813,6 @@ $month_mar = 'Mar';
         phpsource = """define("_FINISH", "Rematar");
 $lang['mediaselect'] = 'Bestand selectie';"""
         phpfile = self.phpparse(phpsource)
-        print(len(phpfile.units))
         assert len(phpfile.units) == 2
         phpunit = phpfile.units[0]
         assert phpunit.name == 'define("_FINISH"'
@@ -614,3 +820,143 @@ $lang['mediaselect'] = 'Bestand selectie';"""
         phpunit = phpfile.units[1]
         assert phpunit.name == "$lang['mediaselect']"
         assert phpunit.source == "Bestand selectie"
+
+    def test_quotes(self):
+        phpsource = b'''<?php
+$txt[\'DISPLAYEDINFOS\'] = "<a href=\\"__PARAM2__\\">Modificar...</a>";
+'''
+        phpfile = self.phpparse(phpsource)
+        assert phpfile.__bytes__() == phpsource
+
+    def test_concatenation(self):
+        """Check that concatenating strings and variables is parsed correctly."""
+        phpsource = """
+$lang['mediaselect'] = "Really \\\"something\\\"" . $variable . "\\\"something else\\\"";
+$messages['welcome'] = 'Welcome ' . $name . '!';
+$messages['greeting'] = 'Hi ' . $name;
+"""
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 3
+        phpunit = phpfile.units[0]
+        assert phpunit.name == "$lang['mediaselect']"
+        assert phpunit.source == "Really \"something\"$variable\"something else\""
+        phpunit = phpfile.units[1]
+        assert phpunit.name == "$messages['welcome']"
+        assert phpunit.source == "Welcome $name!"
+        phpunit = phpfile.units[2]
+        assert phpunit.name == "$messages['greeting']"
+        assert phpunit.source == "Hi $name"
+
+    def test_serialize(self):
+        phpsource = b"""<?php
+# Comment 1
+define("_FINISH", 'Rematar');
+// Comment 2
+define("_START", "Zacni");
+/* Comment 3 */
+$lang['mediaselect'] = 'Bestand selectie';
+$texts = array(
+    /*
+     * Multiline comment 4
+     */
+    'other' => 'Andere',
+    'nested' => array(
+        'and' => 'Und',
+        'second' => 'Zweite',
+    ),
+);
+"""
+        phpfile = self.phpparse(phpsource)
+        assert phpfile.__bytes__() == phpsource
+
+    def test_space_before_comma(self):
+        """check that spacing before comma or semicolon doesn't break parser
+
+        See #1898
+        """
+        phpsource = """
+        $english = array(
+            'item:site'  =>  "Sítios",
+            'login'  =>  "Entrar" ,
+            'loginok'  =>  "Entrou com sucesso." ,
+        );
+        $month_jan = 'Jan';
+        $month_feb = 'Feb'  ;
+        $month_mar = 'Mar';
+        define("_SEARCH","Search");
+        define("_LOGIN","Login"  );
+        define("_POLLS","Polls");
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 9
+
+    def test_equals_in_id(self):
+        """check that equals in id doesn't break parser
+
+        See #1929"""
+        phpsource = """
+        $strings['key = value'] = 'Message';
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        assert phpfile.units[0].source == 'Message'
+        assert phpfile.units[0].name == "$strings['key = value']"
+
+    def test_comma_in_string(self):
+        """check that comma in string doesn't break parser
+
+        See #3608"""
+        phpsource = """
+        $t = array(
+            'key' => ' text (comment **),**',
+        );
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        assert phpfile.units[0].source == ' text (comment **),**'
+        assert phpfile.units[0].name == "$t->'key'"
+
+    def test_nowdoc(self):
+        """check parsing nowdoc strings"""
+        phpsource = """$str = <<<'EOD'
+Example of string
+spanning multiple lines
+using nowdoc syntax.
+EOD;
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 1
+        assert phpfile.units[0].source == '''Example of string
+spanning multiple lines
+using nowdoc syntax.'''
+        assert phpfile.units[0].name == '$str'
+
+    def test_concatenation(self):
+        """check parsing concatenated strings"""
+        phpsource = """$str = 'Concatenated' . ' ' . 'string';
+        $arr['x'] = 'Concatenated' . ' ' . 'string';
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 2
+        assert phpfile.units[0].source == 'Concatenated string'
+        assert phpfile.units[0].name == '$str'
+        assert phpfile.units[1].source == 'Concatenated string'
+        assert phpfile.units[1].name == "$arr['x']"
+
+    def test_array_keys(self):
+        """check parsing different array keys"""
+        phpsource = """
+        $arr = [
+            '1234' => 'First',
+            1234 => 'Second',
+            '12' . '45' => 'Third',
+        ];
+        """
+        phpfile = self.phpparse(phpsource)
+        assert len(phpfile.units) == 3
+        assert phpfile.units[0].source == 'First'
+        assert phpfile.units[0].name == "$arr->'1234'"
+        assert phpfile.units[1].source == 'Second'
+        assert phpfile.units[1].name == "$arr->1234"
+        assert phpfile.units[2].source == 'Third'
+        assert phpfile.units[2].name == "$arr->'1245'"
