@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+import os
+
 import six
 
 from translate.storage import base, po, xliff
@@ -72,6 +74,31 @@ class TestPODebug:
         """Test the unicode rewrite function"""
         assert six.text_type(self.debug.rewrite_unicode(u"Test")) == u"Ŧḗşŧ"
 
+    def test_rewrite_unicode_preserves_at_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_unicode(u"@@ph@@Test @@ph@@")) == u"@@ph@@Ŧḗşŧ @@ph@@"
+
+    def test_rewrite_unicode_preserves_single_brace_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_unicode(u"{ph}Test {ph}")) == u"{ph}Ŧḗşŧ {ph}"
+
+    def test_rewrite_unicode_preserves_double_brace_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_unicode(u"{{ph}}Test {{ph}}")) == u"{{ph}}Ŧḗşŧ {{ph}}"
+
+    def test_rewrite_unicode_preserves_html(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_unicode(u"<style0>Test</style0>")) == u"<style0>Ŧḗşŧ</style0>"
+
+    def test_rewrite_unicode_preserves_multiple_styles_of_placeholder(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_unicode(u"<b>{{ph}}Test{ph}@@ph@@Test</b>")) == u"<b>{{ph}}Ŧḗşŧ{ph}@@ph@@Ŧḗşŧ</b>"
+
     def test_rewrite_flipped(self):
         """Test the unicode rewrite function"""
         assert six.text_type(self.debug.rewrite_flipped(u"Test")) == u"\u202e⊥ǝsʇ"
@@ -81,6 +108,32 @@ class TestPODebug:
         assert six.text_type(self.debug.rewrite_flipped(u" ")) == u"\u202e "
         assert six.text_type(self.debug.rewrite_flipped(u"©")) == u"\u202e©"
 
+    def test_rewrite_flipped_preserves_at_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_flipped(u"@@ph@@Test @@ph@@")) == u"\u202e@@ph@@⊥ǝsʇ @@ph@@"
+
+    def test_rewrite_flipped_preserves_single_brace_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_flipped(u"{ph}Test {ph}")) == u"\u202e{ph}⊥ǝsʇ {ph}"
+
+    def test_rewrite_flipped_preserves_double_brace_placeholders(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_flipped(u"{{ph}}Test {{ph}}")) == u"\u202e{{ph}}⊥ǝsʇ {{ph}}"
+
+    def test_rewrite_flipped_preserves_html(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(debug.rewrite_flipped(u"<style0>Test </style0>")) == u"\u202e<style0>⊥ǝsʇ </style0>"
+
+    def test_rewrite_flipped_multiple_styles_of_placeholder(self):
+        """Test the unicode rewrite function"""
+        debug = podebug.podebug(preserveplaceholders=True)
+        assert six.text_type(
+            debug.rewrite_flipped(u"<b>{{ph}}Test{ph}@@ph@@Test</b>")) == u"\u202e<b>{{ph}}⊥ǝsʇ{ph}@@ph@@⊥ǝsʇ</b>"
+
     def test_rewrite_chef(self):
         """Test the chef rewrite function
 
@@ -157,9 +210,9 @@ msgstr "Test msgstr 3"
         for debug in debugs:
             for po_doc in po_docs:
                 postore = po.pofile(po_doc.encode('utf-8'))
-                postore.filename = "fullpath/to/fakefile.po"
+                postore.filename = os.path.join('fullpath', 'to', 'fakefile.po')
                 po_out = debug.convertstore(postore)
                 in_unit = postore.units[0]
                 out_unit = po_out.units[0]
                 assert in_unit.source == out_unit.source
-                assert out_unit.target == results.pop(0)
+                assert out_unit.target == results.pop(0).replace('/', os.sep)
